pyjabber.plugins.roster package
===============================

Submodules
----------

pyjabber.plugins.roster.Roster module
-------------------------------------

.. automodule:: pyjabber.plugins.roster.Roster
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.plugins.roster
   :members:
   :undoc-members:
   :show-inheritance:
